@@ -48,8 +48,13 @@ class RemoteQueueAdapter(BasisQueueAdapter):
         cores=None,
         memory_max=None,
         run_time_max=None,
+        dependency_list=None,
         command=None,
     ):
+        if dependency_list is not None:
+            raise NotImplementedError(
+                "Submitting jobs with dependencies to a remote cluster is not yet supported."
+            )
         self._transfer_data_to_remote(working_directory=working_directory)
         output = self._execute_remote_command(command=command)
         return int(output.split()[-1])
